# Resthys - Une interface REST partielle pour Noethys
# Copyright (C) 2018  Cliss XXI <tech@cliss21.org>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.conf import settings
from django.http import Http404
from rest_framework import generics

from resthys.base import models, from_noethys, to_noethys
from resthys.base.serializers import (
    FacturesListSerializer,
    FacturesDetailSerializer,
    FacturesPayementSerializer,
    FacturesUnpaySerializer,
    IndividusSerializer,
)


class FacturesList(generics.ListAPIView):
    queryset = models.Factures.objects.exclude(etat="annulation")
    serializer_class = FacturesListSerializer

    def get_queryset(self):
        numeros = self.request.query_params.getlist('numero')
        nom = self.request.GET.get('nom', '')
        return [
            f
            for f in self.queryset.filter(numero__in=numeros)
            if nom == '' or from_noethys.match_facture_names(f, nom)
        ]


class FacturesDetail(generics.RetrieveAPIView):
    queryset = models.Factures.objects.exclude(etat="annulation")
    serializer_class = FacturesDetailSerializer
    lookup_field = 'numero'
    lookup_url_kwarg = 'numero'

    def get_object(self):
        f = super().get_object()
        if 'nom' in self.request.GET:
            if not from_noethys.match_facture_names(f, self.request.GET['nom']):
                raise Http404
        return f


class FacturesPayement(generics.UpdateAPIView):
    queryset = models.Factures.objects.exclude(etat="annulation")
    serializer_class = FacturesPayementSerializer
    lookup_field = 'numero'
    lookup_url_kwarg = 'numero'

    def perform_update(self, serializer):
        if serializer.validated_data['result'] == 'P':
            to_noethys.set_facture_paid(
                    self.get_object(),
                    serializer.validated_data
                    )


class FacturesUnpay(generics.UpdateAPIView):
    queryset = models.Factures.objects.exclude(etat="annulation")
    serializer_class = FacturesUnpaySerializer
    lookup_field = 'numero'
    lookup_url_kwarg = 'numero'

    def perform_update(self, serializer):
        if not settings.DEBUG:
            raise Http404
        to_noethys.set_facture_unpaid(self.get_object())


class IndividusDetail(generics.RetrieveUpdateAPIView):
    queryset = models.Individus.objects.all()
    serializer_class = IndividusSerializer
    lookup_field = 'id'
    lookup_url_kwarg = 'id'
